@@ -1,11 +1,3 @@
-#!/usr/bin/env python3
-# -*- coding: utf-8 -*-
-"""
-Created on Fri Feb 19 11:38:04 2021
-
-@author: zhaoyang
-"""
-
 import pandas as pd
 import numpy as np
 import seaborn as sns
@@ -205,7 +197,6 @@ class Feature_Evalution:
     
     def feature_importance(self,methods):
         result = pd.DataFrame()
-        exclude_cols.append(self.label)
         result['feature'] = self.data.drop(exclude_cols,axis=1).columns.values.tolist()
         result['rank_sum'] = 0
         if 'iv' in methods:        
@@ -243,7 +234,6 @@ class Feature_Evalution:
     # 特征相关系数
 
     def corr_analysis(self):
-        exclude_cols.append(self.label)
         xnames = self.data.drop(self.exclude_cols,axis=1).columns.values.tolist()
         corr = self.data[xnames].corr()
         return corr
@@ -253,7 +243,6 @@ class Feature_Evalution:
     def data_preprocessing(self):
         
         minmax = preprocessing.MinMaxScaler()
-        exclude_cols.append(self.label)
         xnames = self.data.drop(self.exclude_cols,axis=1).columns.values.tolist()
         data_minmax = minmax.fit_transform(self.data[xnames])
 
@@ -436,7 +425,7 @@ class Feature_Evalution:
         psi_res['feature']=dp_calcindex['feature']
         psi_res['max_psi']=dp_calcindex['psi']['max']
         psi_res['min_psi']=dp_calcindex['psi']['min']
-        psi_res['mean_pi']=dp_calcindex['psi']['mean']
+        psi_res['mean_psi']=dp_calcindex['psi']['mean']
         psi_res['std_psi']=dp_calcindex['psi']['std']
         return psi_res
 
